@@ -62,7 +62,7 @@ class SingularityClient(ContainerClient):
         singularity_compose_is_installed = singularity_compose_sys is not None
 
         if not singularity_compose_is_installed:
-            LOGGER.fatal("The command 'singularity-compose' is not installed. Visit https://singularityhub.github.io/singularity-compose/ for more information.")
+            LOGGER.fatal("The command 'singularity-compose' is not installed. 'singularity-compose' should be installed using `pip install git+ssh://git@github.com/AaronYoung5/singularity-compose` (or the https equivalent).")
 
         return singularity_is_installed and singularity_compose_is_installed
 
@@ -132,42 +132,6 @@ class SingularityClient(ContainerClient):
 
         self.config.write_compose(compose)
 
-    def build(self, *args) -> bool:
-        """Build the images.
-
-        ``singularity-compose`` won't overwrite an existing sif it already exists. Do that here.
-
-        Returns:
-            bool: Whether the command succeeded.
-        """
-
-        for service_name, service in self.config.compose["instances"].items():
-            if service_name not in self._services or "build" not in service:
-                continue
-
-            build = service["build"]
-
-            sif = Path(build.get("context", ".")) / f"{service_name}.sif"
-            if sif.exists():
-                res = input(f"The image for {service_name} has already been built. Okay to overwrite? (y|[n]) ") or "n"
-                if res == "y":
-                    os.unlink(sif)
-                elif res == "n":
-                    LOGGER.info(f"Not overwriting {service_name}.sif.")
-                else:
-                    LOGGER.warn(f"Response '{res}' is not recognized. Pass either 'y' or 'n'. Not overwriting {service_name}.sif.")
-        return super().build(*args)
-
-    def up(self, *args) -> bool:
-        """Bring up the containers.
-
-        Returns:
-            bool: Whether the command succeeded.
-        """
-        if "--resolv" not in args:
-            args = [*args, "--no-resolv"]
-        return super().up(*args)
-
     def run(self, service, *exec_cmd) -> bool:
         """Run a command in a container.
 
@@ -206,7 +170,7 @@ class SingularityClient(ContainerClient):
         If cmd is equal to ``exec``, ``exec_cmd`` will expect to be passed as a named argument. 
         If not, a :class:`ContainerException` will be thrown.
 
-        Additional positional args (*args) will be passed as command arguments when running the command. 
+        Additional positional args (``*args``) will be passed as command arguments when running the command. 
         Named arguments will be passed to :meth:`subprocess.run` 
         (`see their docs <https://docs.python.org/3/library/subprocess.html#subprocess.run>`_).
 
